@@ -1,6 +1,10 @@
-from telethon import events, TelegramClient
-from tgcf.config import CONFIG, API_HASH, API_ID, SESSION
+import logging
 
+from telethon import TelegramClient, events
+
+from tgcf.config import API_HASH, API_ID, CONFIG, SESSION
+from tgcf.plugins import apply_plugins
+from tgcf.utils import send_message
 
 from_to = {}
 
@@ -24,7 +28,7 @@ class EventUid:
             self.msg_id = event.deleted_id
 
     def __str__(self):
-        return f'chat={self.chat_id} msg={self.msg_id}'
+        return f"chat={self.chat_id} msg={self.msg_id}"
 
     def __eq__(self, other):
         return self.chat_id == other.chat_id and self.msg_id == other.msg_id
@@ -38,7 +42,7 @@ async def new_message_handler(event):
 
     if chat_id not in from_to:
         return
-
+    logging.info(f"New message received in {chat_id}")
     message = event.message
 
     global _stored
@@ -59,8 +63,11 @@ async def new_message_handler(event):
         if event_uid not in _stored:
             _stored[event_uid] = []
 
+        message = apply_plugins(message)
+        if not message:
+            return
         for recipient in to_send_to:
-            fwded_msg = await event.client.send_message(recipient, message)
+            fwded_msg = await send_message(event.client, recipient, message)
             _stored[event_uid].append(fwded_msg)
 
     existing_hashes.append(hash(message.text))
@@ -70,43 +77,64 @@ async def edited_message_handler(event):
     message = event.message
 
     chat_id = event.chat_id
-    if chat_id in from_to:
 
-        event_uid = EventUid(event)
+    if chat_id not in from_to:
+        return
 
-        fwded_msgs = _stored.get(event_uid)
-        if fwded_msgs:
-            for msg in fwded_msgs:
+    logging.info(f"Message edited in {chat_id}")
+
+    event_uid = EventUid(event)
+
+    message = apply_plugins(message)
+
+    if not message:
+        return
+
+    fwded_msgs = _stored.get(event_uid)
+
+    if fwded_msgs:
+        for msg in fwded_msgs:
+            if CONFIG.live.delete_on_edit == message.text:
+                await msg.delete()
+                await message.delete()
+            else:
                 await msg.edit(message.text)
-            return
-        else:
-            to_send_to = from_to.get(event.chat_id)
-            for recipient in to_send_to:
-                await event.client.send_message(recipient, message)
+        return
+
+    to_send_to = from_to.get(event.chat_id)
+
+    for recipient in to_send_to:
+        await send_message(event.client, recipient, message)
 
 
 async def deleted_message_handler(event):
     chat_id = event.chat_id
-    if chat_id in from_to:
-        event_uid = EventUid(event)
-        fwded_msgs = _stored.get(event_uid)
-        if fwded_msgs:
-            for msg in fwded_msgs:
-                await msg.delete()
-            return
+    if chat_id not in from_to:
+        return
+
+    logging.info(f"Message deleted in {chat_id}")
+
+    event_uid = EventUid(event)
+    fwded_msgs = _stored.get(event_uid)
+    if fwded_msgs:
+        for msg in fwded_msgs:
+            await msg.delete()
+        return
 
 
 ALL_EVENTS = {
-    'new': (new_message_handler, events.NewMessage()),
-    'edited': (edited_message_handler, events.MessageEdited()),
-    'deleted': (deleted_message_handler, events.MessageDeleted())
+    "new": (new_message_handler, events.NewMessage()),
+    "edited": (edited_message_handler, events.MessageEdited()),
+    "deleted": (deleted_message_handler, events.MessageDeleted()),
 }
 
 
 def start_sync():
     client = TelegramClient(SESSION, API_ID, API_HASH)
     for key, val in ALL_EVENTS.items():
-        print(f'Adding event {key}')
+        if CONFIG.live.delete_sync is False and key == "deleted":
+            continue
         client.add_event_handler(*val)
+        logging.info(f"Added event handler for {key}")
     client.start()
     client.run_until_disconnected()
